@@ -6,7 +6,7 @@
  * Portions Copyright (c) 2000-2002 by Gilbert Ramirez.
  * Portions Copyright (c) Novell, Inc. 2002-2003
  *
- * $Id: packet-ipx.c 26647 2008-10-31 15:11:57Z stig $
+ * $Id: packet-ipx.c 35168 2010-12-10 12:13:53Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -297,12 +297,12 @@ dissect_ipx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		ipx_tree = proto_item_add_subtree(ti, ett_ipx);
 	}
 
-	str=address_to_str(&pinfo->net_src);
+	str=ep_address_to_str(&pinfo->net_src);
 	hidden_item = proto_tree_add_string(ipx_tree, hf_ipx_src, tvb, 0, 0, str);
 	PROTO_ITEM_SET_HIDDEN(hidden_item);
 	hidden_item = proto_tree_add_string(ipx_tree, hf_ipx_addr, tvb, 0, 0, str);
 	PROTO_ITEM_SET_HIDDEN(hidden_item);
-	str=address_to_str(&pinfo->net_dst);
+	str=ep_address_to_str(&pinfo->net_dst);
 	hidden_item = proto_tree_add_string(ipx_tree, hf_ipx_dst, tvb, 0, 0, str);
 	PROTO_ITEM_SET_HIDDEN(hidden_item);
 	hidden_item = proto_tree_add_string(ipx_tree, hf_ipx_addr, tvb, 0, 0, str);
@@ -787,6 +787,7 @@ dissect_spx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	}
 
 	if (tvb_reported_length_remaining(tvb, SPX_HEADER_LEN) > 0) {
+		void* pd_save;
 		/*
 		 * Call subdissectors based on the IPX socket numbers; a
 		 * subdissector might have registered with our IPX socket
@@ -815,16 +816,24 @@ dissect_spx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		 */
 		spx_info.eom = conn_ctrl & SPX_EOM;
 		spx_info.datastream_type = datastream_type;
+		pd_save = pinfo->private_data;
 		pinfo->private_data = &spx_info;
 
 		next_tvb = tvb_new_subset(tvb, SPX_HEADER_LEN, -1, -1);
 		if (dissector_try_port(spx_socket_dissector_table, low_socket,
 		    next_tvb, pinfo, tree))
+		{
+			pinfo->private_data = pd_save;
 			return;
+		}
 		if (dissector_try_port(spx_socket_dissector_table, high_socket,
 		    next_tvb, pinfo, tree))
+		{
+			pinfo->private_data = pd_save;
 			return;
+		}
 		call_dissector(data_handle, next_tvb, pinfo, tree);
+		pinfo->private_data = pd_save;
 	}
 }
 
