@@ -1,6 +1,7 @@
 #!/bin/bash
-#
-# $Id: win32-setup.sh 30954 2009-11-13 20:20:40Z gerald $
+(set -o igncr) 2>/dev/null && set -o igncr;  # hack to force this file to be processed by cygwin bash with -o igncr
+                                             # needed when this file is exec'd from win64-setup.sh
+# $Id: win32-setup.sh 36574 2011-04-12 00:43:52Z gerald $
 
 # This MUST be in the form
 #   http://anonsvn.wireshark.org/wireshark-win32-libs/tags/<date>/packages
@@ -9,7 +10,7 @@
 # in order to provide backward compatibility with older trees (e.g. a
 # previous release or an older SVN checkout).
 # Save previous tag.
-DOWNLOAD_TAG=${DOWNLOAD_TAG:-"2009-11-13-1.2"}
+DOWNLOAD_TAG=${DOWNLOAD_TAG:-"2011-04-11-1.2"}
 WIRESHARK_TARGET_PLATFORM=${WIRESHARK_TARGET_PLATFORM:-"win32"}
 
 DOWNLOAD_PREFIX="http://anonsvn.wireshark.org/wireshark-$WIRESHARK_TARGET_PLATFORM-libs/tags/$DOWNLOAD_TAG/packages/"
