@@ -2,7 +2,7 @@
  * File read and write routines for Visual Networks cap files.
  * Copyright (c) 2001, Tom Nisbet  tnisbet@visualnetworks.com
  *
- * $Id: visual.c 22612 2007-08-23 22:11:39Z sfisher $
+ * $Id: visual.c 37213 2011-05-17 21:30:50Z gerald $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -220,33 +220,38 @@ int visual_open(wtap *wth, int *err, gchar **err_info)
         return -1;
     }
 
-    /* Translate the encapsulation type.  Note that a file with media
-       type 22 may contain Cisco HDLC or PPP over HDLC.  This will
-       get sorted out after the first packet is read. */
+    /* Translate the encapsulation type; these values are SNMP ifType
+       values, as found in http://www.iana.org/assignments/smi-numbers.
+
+       Note that a file with media type 22 ("propPointToPointSerial") may
+       contain Cisco HDLC or PPP over HDLC.  This will get sorted out after
+       the first packet is read.
+
+       XXX - should we use WTAP_ENCAP_PER_PACKET for that? */
     switch (pletohs(&vfile_hdr.media_type))
     {
-    case  6:
+    case  6:	/* ethernet-csmacd */
         encap = WTAP_ENCAP_ETHERNET;
         break;
 
-    case  9:
+    case  9:	/* IEEE802.5 */
         encap = WTAP_ENCAP_TOKEN_RING;
         break;
 
-    case 16:
+    case 16:	/* lapb */
         encap = WTAP_ENCAP_LAPB;
         break;
 
-    case 22:
-    case 118:
+    case 22:	/* propPointToPointSerial */
+    case 118:	/* HDLC */
         encap = WTAP_ENCAP_CHDLC_WITH_PHDR;
         break;
 
-    case 32:
+    case 32:	/* frame-relay */
         encap = WTAP_ENCAP_FRELAY_WITH_PHDR;
         break;
 
-    case 37:
+    case 37:	/* ATM */
        encap = WTAP_ENCAP_ATM_PDUS;
        break;
 
@@ -299,7 +304,6 @@ static gboolean visual_read(wtap *wth, int *err, gchar **err_info,
     int ahdr_size = sizeof(vatm_hdr);
     time_t  secs;
     guint32 usecs;
-    guint8 *buf;
     double  t;
 
     /* Check for the end of the packet data.  Note that a check for file EOF
@@ -418,6 +422,15 @@ static gboolean visual_read(wtap *wth, int *err, gchar **err_info,
        break;
     }
 
+    if (wth->phdr.len > WTAP_MAX_PACKET_SIZE) {
+    /* Check if wth->phdr.len is sane, small values of wth.phdr.len before
+       the case loop above can cause integer underflows */ 
+        *err = WTAP_ERR_BAD_RECORD;
+        *err_info = g_strdup_printf("visual: File has %u-byte original packet, bigger than maximum of %u",
+                    wth->phdr.len, WTAP_MAX_PACKET_SIZE);
+        return FALSE;
+    }
+
     /* Sanity check */
     if (wth->phdr.len < wth->phdr.caplen)
     {
@@ -429,16 +442,32 @@ static gboolean visual_read(wtap *wth, int *err, gchar **err_info,
 
     /* Fill in the encapsulation.  Visual files have a media type in the
        file header and an encapsulation type in each packet header.  Files
-       with a media type of HDLC can be either Cisco EtherType or PPP. */
+       with a media type of HDLC can be either Cisco EtherType or PPP.
+
+       The encapsulation hint values we've seen are:
+
+         2 - seen in an Ethernet capture
+         13 - seen in a PPP capture; possibly also seen in Cisco HDLC
+              captures
+         14 - seen in a PPP capture; probably seen only for PPP */
     if (wth->file_encap == WTAP_ENCAP_CHDLC_WITH_PHDR)
     {
-        /* examine first two octets to verify encapsulation */
-        buf = buffer_start_ptr(wth->frame_buffer);
-        if ((0xff == buf[0]) && (0x03 == buf[1]))
+        /* If PPP is specified in the encap hint, then use that */
+        if (vpkt_hdr.encap_hint == 14)
         {
-            /* It is actually PPP */
             wth->phdr.pkt_encap = WTAP_ENCAP_PPP_WITH_PHDR;
         }
+        else
+        {
+            /* Otherwise, we need to examine the first two octets to
+               try to determine the encapsulation. */
+            guint8 *buf = buffer_start_ptr(wth->frame_buffer);
+            if ((0xff == buf[0]) && (0x03 == buf[1]))
+            {
+                /* It is actually PPP */
+                wth->phdr.pkt_encap = WTAP_ENCAP_PPP_WITH_PHDR;
+            }
+        }
     }
     return TRUE;
 }
@@ -474,7 +503,7 @@ static gboolean visual_seek_read (wtap *wth, gint64 seek_off,
     /* If ATM capture, need to skip over visual ATM packet header too */
     if (wth->file_encap == WTAP_ENCAP_ATM_PDUS)
     {
-       header_size += sizeof(struct visual_atm_hdr);
+       header_size += (int)sizeof(struct visual_atm_hdr);
     }
     
     /* Seek to the packet header */
@@ -799,7 +828,7 @@ static gboolean visual_dump(wtap_dumper *wdh, const struct wtap_pkthdr *phdr,
 
     /* Update the table index and offset for the next frame. */
     visual->index_table_index++;
-    visual->next_offset += hdr_size + phdr->caplen;
+    visual->next_offset += (guint32) hdr_size + phdr->caplen;
 
     return TRUE;
 }
@@ -866,7 +895,7 @@ static gboolean visual_dump_close(wtap_dumper *wdh, int *err)
     vfile_hdr.max_length = htoles(65535);
     vfile_hdr.file_flags = htoles(1);  /* indexes are present */
     vfile_hdr.file_version = htoles(1);
-    strcpy(vfile_hdr.description, "Wireshark file");
+    g_strlcpy(vfile_hdr.description, "Wireshark file", 64);
 
     /* Translate the encapsulation type */
     switch (wdh->encap)
